@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 try:
     from kombu.transport import TRANSPORT_ALIASES
@@ -8,5 +8,5 @@ try:
 except ImportError:
     pass
 else:
-    TRANSPORT_ALIASES['tarantool'] = 'python_utils.celery:TarantoolTransport'
-    BACKEND_ALIASES['tarantool'] = 'python_utils.celery:TarantoolBackend'
+    TRANSPORT_ALIASES['tarantool'] = 'tarantool_utils.celery:TarantoolTransport'
+    BACKEND_ALIASES['tarantool'] = 'tarantool_utils.celery:TarantoolBackend'
